TaPlaylistController class
- Inheritance
-
- Object
- ChangeNotifier
- TaPlaylistController
Constructors
-
TaPlaylistController({required List<
TaVideoSource> sources, int preloadCount = 2})
Properties
- currentController → TaVideoController?
-
no setter
- currentIndex → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- preloadCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
→ List<
TaVideoSource> -
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
getControllerAt(
int index) → TaVideoController? -
initialize(
) → void -
jumpTo(
int index) → void -
next(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
previous(
) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited