TaVideoController class

Inheritance

Constructors

TaVideoController({required TaVideoSource source})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source TaVideoSource
final
value TaPlayerState
The current value stored in this notifier.
getter/setter pairinherited
videoPlayerController → VideoPlayerController?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
initialize() Future<void>
mute() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pause() Future<void>
play() Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
seekTo(Duration position) Future<void>
setVolume(double volume, {bool syncWithSystem = true}) Future<void>
toggleMute() Future<void>
toString() String
A string representation of this object.
inherited
unmute() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

globalMute ValueNotifier<bool>
final