TaCacheManager class

Constructors

TaCacheManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ↔ CacheManager
getter/setter pair

Static Methods

getCachedPath(String url) Future<String?>
Gets a cached file for a URL
preCacheVideo(String url) Future<void>
Pre-caches a video URL

Constants

key → const String