TaPlayerState class
Constructors
- TaPlayerState({TaPlayerStatus status = TaPlayerStatus.initial, Duration position = Duration.zero, Duration duration = Duration.zero, Duration buffered = Duration.zero, double volume = 1.0, double speed = 1.0, bool isMuted = false, bool isFullscreen = false, String? errorMessage})
Properties
- buffered → Duration
-
final
- duration → Duration
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFullscreen → bool
-
final
- isMuted → bool
-
final
- position → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
final
- status → TaPlayerStatus
-
final
- volume → double
-
final
Methods
-
copyWith(
{TaPlayerStatus? status, Duration? position, Duration? duration, Duration? buffered, double? volume, double? speed, bool? isMuted, bool? isFullscreen, String? errorMessage}) → TaPlayerState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited